/*--------------------------------------------------------------------------
 Dataset:              180308_PRM_2.0.dta
 Authors:	           Aurel Croissant, Tanja Eschenauer, Jil Kamerling
 Date:			       March 08, 2018
 -------------------------------------------------------------------------*/

use "180308_PRM_2.0.dta", clear

* Replace codes for missings as stata missing code
replace raw_veto=. if raw_veto>1
replace raw_origin=. if raw_origin>1
replace raw_leader=. if raw_leader>1
replace raw_mod=. if raw_mod>1
replace raw_impun=. if raw_impun>1
replace raw_repress=. if raw_repress>1

* Means across BTI versions
egen country_bti=concat(country bti_version), punct(" ")
bysort country_bti: egen mi_veto=mean(raw_veto)
bysort country_bti: egen mi_origin=mean(raw_origin)
bysort country_bti: egen mi_leader=mean(raw_leader)
bysort country_bti: egen mi_mod=mean(raw_mod)
bysort country_bti: egen mi_impun=mean(raw_impun)
bysort country_bti: egen mi_repress=mean(raw_repress)

* Military ruler score
generate mi_ruler = .
replace mi_ruler = min(mi_origin, max(mi_leader, mi_mod)) ///
  if mi_origin!=.

* Military supporter score
generate mi_supporter = .
replace mi_supporter = max( ///
  min(mi_veto, mi_repress), ///
  min(mi_veto, mi_impun), ///
  min(mi_repress, mi_impun)) ///
  if mi_veto!=. & mi_impun!=. & mi_repress!=.

* Military influence score
gen mi_in=.
replace mi_in=1 if mi_ruler>=0.5 & mi_ruler!=.
replace mi_in=2 if mi_supporter>=0.5 & mi_supporter!=.
replace mi_in=3 if mi_ruler>=0.5 & mi_supporter>=0.5 & ///
  mi_ruler!=. & mi_supporter!=.
replace mi_in=0 if mi_ruler<0.5 & mi_supporter<0.5 & ///
  mi_ruler!=. & mi_supporter!=.
  
label define mi_in ///
 0 "no Military influence" 1 "Military ruler" 2 "Military supporter" ///
 3 "Military ruler and supporter"
label values mi_in mi_in 
